@@ -120,7 +120,8 @@ class JoplinDataWrapper:
     def save_resource_to_file(self, resource: JoplinResource):
         file_download = self.REST.rest_get('/resources/{}/file'.format(resource.id), None)
         full_path = tempfile.mktemp(dir=tempfile.tempdir)
-        open(full_path, 'wb').write(file_download.content)
+        with open(full_path, 'wb') as f:
+            f.write(file_download.content)
         return full_path
 
     def get_note_resources(self, note_id):
@@ -132,10 +133,11 @@ class JoplinDataWrapper:
         return JoplinResource(res.json())
 
     def save_preview_image_as_resource(self, note_id, filename: str, title: str):
-        props = f'{{"title":"{title}", "filename":"{title}.png"}}'
-        files = {
-            "data": (json.dumps(filename), open(filename, "rb")),
-            "props": (None, props),
-        }
-        res = self.REST.rest_post("/resources/{}".format(note_id), files=files)
-        return res.json()["id"]
+        with open(filename, "rb") as file:
+            props = f'{{"title":"{title}", "filename":"{title}.png"}}'
+            files = {
+                "data": (json.dumps(filename), file),
+                "props": (None, props),
+            }
+            res = self.REST.rest_post("/resources/{}".format(note_id), files=files)
+            return res.json()["id"]
